@@ -3,7 +3,7 @@ import logging
 import socket
 import time
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 
 from .data import LIP_PROTOCOL_MODE_TO_LIPMODE, LIPMessage, LIPMode
 from .exceptions import LIPConnectionStateError, LIPProtocolError
@@ -187,7 +187,9 @@ class LIP:
 
         try:
             self._process_message(read_task.result())
-        except (asyncio.TimeoutError, BrokenPipeError) as ex:
+        except asyncio.TimeoutError:
+            return
+        except BrokenPipeError as ex:
             _LOGGER.debug("Error processing message", exc_info=ex)
             return
 
